<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://webmuehle.at
 * @since      1.0.3
 *
 * @package    Courtres
 * @subpackage Courtres/admin/partials
 */
?>

<?php

if (!current_user_can('manage_options')) {
    wp_die();
}

global $wpdb;
$table_name = $this->getTable('courts');

if (isset($_GET['courtID'])) {
    $courtID = (int) $_GET['courtID'];
}

// 17.01.2019, astoian - if not premium, stop it
if (isset($courtID) && !$this->isCourtPremium($courtID)) {
  include 'courtres-notice-upgrade.php';
  wp_die(__("Free version allow one Court only.", 'courtres'));
}

if (isset($_POST['delete']) && isset($_POST['id']) && (int) $_POST['id'] > 0) { // delete
    $wpdb->delete($table_name, array('id' => (int) $_POST['id']));
}

if (isset($_POST['submit'])) {
    if (isset($_POST['id']) && (int) $_POST['id'] > 0) { // edit
        $wpdb->update($table_name,
            array(
                'name' => $_POST['name'],
                'open' => $_POST['open'],
                'close' => $_POST['close'],
                'days' => $_POST['days'],
            ),
            array('id' => (int) $_POST['id']),
            array(
                '%s',
                '%d',
                '%d',
                '%d',
            ));
        $courtID = (int) $_POST['id'];
        $message = __('Successfully changed!', 'courtres');
    } else { // create
        $wpdb->insert($table_name,
            array(
                'name' => $_POST['name'],
                'open' => $_POST['open'],
                'close' => $_POST['close'],
                'days' => $_POST['days'],
            ),
            array(
                '%s',
                '%d',
                '%d',
                '%d',
            ));
        $message = __('Successfully created!', 'courtres');
        $courtID = $wpdb->insert_id;
    }
}

if (isset($courtID) && $courtID > 0) {
    $court = $wpdb->get_row("SELECT * FROM $table_name WHERE id = $courtID");
}

if (!isset($court)) {
    $court = new stdClass();
    $court->id = 0;
    $court->name = '';
    $court->open = 8;
    $court->close = 22;
    $court->days = 3;
}
?>

<div class="wrap">
  <a class="page-title-action" href="<?=admin_url("admin.php?page=courtres")?>"><?=__('Back', 'courtres');?></a>
  <h1 class="wp-heading-inline"><?=(isset($court) && $court->id > 0) ? $court->name . __(' edit', 'courtres') : __('Create Court', 'courtres')?></h1>
  <hr class="wp-header-end">

  <form method="post">
    <input type="hidden" name="id" value="<?=$court->id?>" />
    <table>
      <tr>
        <td><?=__('Name', 'courtres');?></td>
        <td><input type="text" name="name" maxlength="255" value="<?=$court->name?>" required /></td>
      </tr>
      <tr>
        <td><?=__('Opens (hour)', 'courtres');?></td>
        <td><input type="number" name="open" min="0" max="23" maxlength="2" value="<?=$court->open?>" required /></td>
      </tr>
      <tr>
        <td><?=__('Closes (hour)', 'courtres');?></td>
        <td><input type="number" name="close" min="0" max="24" maxlength="2" value="<?=$court->close?>" required /></td>
      </tr>
      <tr>
        <td><?=__('Reservation Days in Advance', 'courtres');?></td>
        <td><input type="number" name="days" min="0" max="9" maxlength="1" value="<?=$court->days?>" required /></td>
      </tr>
      <tr>
        <td></td>
        <td><input class="button" type="submit" name="submit" value=<?= __('Save', 'courtres');?> /></td>
      </tr>
      <?php if (isset($court) && $court->id > 0) {?>
        <tr>
          <td colspan="2"><hr/></td>
        </tr>
        <tr>
          <td><?=__('Delete Court', 'courtres');?></td>
          <td><input class="button" type="submit" name="delete" value=<?=__('Delete', 'courtres');?> /></td>
        </tr>
      <?php }?>
  </form>
</div>
</div>
</div>
