<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://webmuehle.at
 * @since      1.0.3
 *
 * @package    Courtres
 * @subpackage Courtres/admin/partials
 */
?>

<?php
if (!current_user_can('manage_options')) {
	wp_die();
}
$message_error = "";
$message_errors = array();
$days = $this->getWeekdays();
$is_created = false;
$is_deleted = false;

$tab = (!empty($_GET['tab'])) ? esc_attr($_GET['tab']) : '0';

global $wpdb;
$table_name = $this->getTable('events');
$table_courts = $this->getTable('courts');

//18.01.2019, astoian - if not premium, show only 1 court
if ($this->isCourtsAdd()) {
	$courts = $wpdb->get_results("SELECT * FROM $table_courts ORDER BY name");
} else {
	$court = $wpdb->get_row("SELECT * FROM $table_courts ORDER BY id");
	$courts = array($court);
}

if (isset($_GET['eventID'])) {
	$eventID = (int) $_GET['eventID'];
}

if (isset($_POST['delete']) && isset($_POST['id']) && (int) $_POST['id'] > 0) { // delete
	$res = $wpdb->delete($table_name, array('id' => (int) $_POST['id']));
	if($res){
		$is_deleted = true;
		$message = __('Succesfully deleted', 'courtres');
	}
}

$is_half_hour_reservation = $this->getOptionValue("half_hour_reservation");

// declare and init vars
$is_insert_update = false;
$id = false;
$start_ts = false;
$end_ts = false;

// check POST
$court_id = isset($_POST['courtid']) && $_POST['courtid'] ? $_POST['courtid'] : false;
$name = isset($_POST['name']) && $_POST['name'] ? sanitize_text_field($_POST['name']) : false;
$curEventWeeklyRepeat = isset($_POST['weekly_repeat']) && $_POST['weekly_repeat'] ? $_POST['weekly_repeat'] : 0;
$event_date = isset($_POST['event_date']) && $_POST['event_date'] ? sanitize_text_field($_POST['event_date']) : false;
$start_h = isset($_POST['start']) && $_POST['start'] ? intval($_POST['start']) : false;
$end_h = isset($_POST['end']) && $_POST['end'] ? intval($_POST['end']) : false;
$start_m = isset($_POST['start_m']) && $_POST['start_m'] ? sanitize_text_field($_POST['start_m'] ) : false;
$end_m = isset($_POST['end_m']) && $_POST['end_m'] ? sanitize_text_field($_POST['end_m']) : false;
$dow = isset($_POST['event_date_week']) && $_POST['event_date_week'] ? intval($_POST['event_date_week']) : false;


// submitted form >
if (isset($_POST['submit'])) {
	// declare vars
	$is_insert_update = true;
	$event_timestamp = $event_date ? strtotime($event_date) : false;

	// check courts existing
	if (!$court_id) {
		$message_errors[] = __("Please create a court first.", 'courtres');
		$is_insert_update = false;
	}
	//
	
	$posted_start_time = (int) $start_h + (int) $start_m / 60;
	$posted_end_time = (int) $end_h + (int) $end_m / 60;

	if( ($event_date || $curEventWeeklyRepeat) && $start_h && $start_m ){
		$start_datetime = $event_date . " " . $start_h .  ":" . $start_m;
		$start_ts = strtotime($start_datetime);
	}
	if( ($event_date || $curEventWeeklyRepeat) && $end_h && $end_m ){
		$end_datetime = $event_date. " " . $end_h .  ":" . $end_m;
		$end_ts = strtotime($end_datetime);
	}


	// if($this->get_version() >= "1.5.0"){}

	if ($posted_start_time >= $posted_end_time) {
		$message_errors[] = __('Start must be before end of event.', 'courtres');
	} else {

		/*  Check events time slots  */
		$id = (isset($_POST['id']) && (int) $_POST['id'] > 0) ? (int) $_POST['id'] : 0;

		$result = $this->create_event(array(
			"name" => $name, 
			"court_id" => $court_id, 
			"event_date" => $event_date,
			"start" => array("h" => $start_h, "m" => $start_m), 
			"end" =>  array("h" => $end_h, "m" => $end_m),
			"event_id" => $id,
			"is_event_weekly_repeat" => $curEventWeeklyRepeat,
			"event_date_week" => $dow,
			"check_all" => true,
		));

		$message_errors = $result["errors"];
		if(!$message_errors){
			$eventID = $result["success"]["event_id"];
			$message = $result["success"]["message"];
			$is_created = true;
		}
	}
}
// < submitted form

// Defaults
$event = false;
if (isset($eventID) && $eventID) {
	$event = $wpdb->get_row("SELECT * FROM $table_name WHERE id = $eventID");
}
if($event){
	$event->event_date = $event->event_date == "0000-00-00" ? "" : mysql2date("d-m-Y", $event->event_date);
	$event->start_m = $event->start_ts ? date_i18n('i', $event->start_ts) : "";
	$event->end_m = $event->end_ts ? date_i18n('i', $event->end_ts) : "";
	$event->dow = $event->dow ? $event->dow : date('w', strtotime($event->event_date));
	if($event->type == "challenge"){
		$message_errors[] = __("You can not edit challenges here");
	}
}else{
	$event = new stdClass();
	$event->id = 0;
	$event->name = $name;
	$event->start = $start_h;
	$event->end = $end_h;
	$event->repeatone = null;
	$event->dow = $dow;
	$event->courtid = 0;
	$event->event_date = $event_date;
	$event->weekly_repeat = $curEventWeeklyRepeat;
	$event->start_m = $start_m;
	$event->end_m = $end_m;
	$event->type = null;
}
?>


<div class="wrap">

	<?php if (isset($message) && $message) {?>
		<div id="message" class="updated notice is-dismissible"><p>
			<?=$message?>
		</p></div>
	<?php }?>

	<?php if ($message_errors) :?>
		<?php foreach ($message_errors as $message_error):?>
			<div id="message" class="notice notice-error is-dismissible"><p>
				<?php 
				if(is_array($message_error)){
					echo implode("<br />", $message_error);
				}else{
					echo $message_error;
				}
				?>
			</p></div>
		<?php endforeach; ?>
	<?php endif; ?>

	<a class="page-title-action" href="<?=admin_url("admin.php?page=courtres-events&tab=$tab")?>"><?=__('Back', 'courtres');?></a>
	<h1 class="wp-heading-inline">
	
	<?php
	if ($tab == '1') {
		$create = __('Create weekly event', 'courtres');
		$edit = __('Edit weekly event', 'courtres');
	} else {
		$create = __('Create individual event', 'courtres');
		$edit = __('Edit individual event', 'courtres');
	}
	?>
	<?php
	if($is_deleted){
		$h1 = "Event Deleted";
	}else{
		$h1 = (isset($event) && $event->id > 0) ? $event->name . " - " . $edit : $create;
	}
	echo $h1;
	?>
	</h1>
	<hr class="wp-header-end">

	<?php if ($event->type != "challenge" && !$is_created && !$is_deleted) :?>

		<form method="post">
			<input type="hidden" name="id" value="<?=$event->id?>" />
			<table class="t-form">
				<tr>
					<td><?=__('Name', 'courtres');?></td>
					<td><input type="text" name="name" maxlength="255" value="<?=$event->name?>" required /></td>
				</tr>
				<?php if ($tab == '1') { ?>
					 <tr>
						<td><?=__('Repeat weekly', 'courtres');?></td>
						<td><input type="hidden" name="weekly_repeat" value="1" checked /></td>
					</tr>
					<tr>
						<td><?=__('Date of weekly events', 'courtres');?></td>
						<td>
							<select name="event_date_week">
								<?php for ($dowi = 0; $dowi < sizeof($days); $dowi++) {?>
									<option value="<?=$dowi; ?>" <?php selected( $dowi, $event->dow ); ?>><?=$days[$dowi]?></option>
								<?php }?>
							</select>
						</td>
					</tr>
				<?php } else { ?>
					<tr>
						<td><?=__('Date of the event', 'courtres');?></td>
						<td>
							<input type="text" name="event_date" class="datepicker" data-eventdateformat = "dd-mm-yy" value="<?=$event->event_date;?>" required>
						</td>
					</tr>
				<?php } ?>
				<tr>
					<td><?=__('Start', 'courtres');?></td>
					<td>
						<input type="number" name="start" min="0" max="23" maxlength="2" value="<?=$event->start?>" required />&nbsp;:&nbsp;
						<select name="start_m" id="select-start-m">
							<option value="00" <?php selected($event->start_m, "00"); ?>>00</option>
							<option value="30" <?php selected($event->start_m, "30"); ?>>30</option>
						</select>
					</td>
				</tr>
				<tr>
					<td><?=__('End', 'courtres');?></td>
					<td>
						<input type="number" name="end" min="0" max="23" maxlength="2" value="<?=$event->end?>" required />&nbsp;:&nbsp;
						<select name="end_m" id="select-end-m">
							<option value="00" <?php selected($event->end_m, "00"); ?>>00</option>
							<option value="30" <?php selected($event->end_m, "30"); ?>>30</option>
						</select>
					</td>
				</tr>
				<tr>
					<td><?=__('Court', 'courtres');?></td>
					<td>
						<select name="courtid">
							<?php for ($i = 0; $i < sizeof($courts); $i++) {$item = $courts[$i];?>
								<option value="<?=$item->id?>" <?=($item->id == $event->courtid) ? 'selected' : ''?>><?=$item->name?></option>
							<?php }?>
						</select>
					</td>
				</tr>
				<tr>
					<td></td>
					<td><input class="button" type="submit" name="submit" value=<?=__('Save', 'courtres');?> /></td>
				</tr>

				<?php if (isset($event) && $event->id > 0) {?>
					<tr>
						<td colspan="2"><hr/></td>
					</tr>
					<tr>
						<td><?=__('Delete Event', 'courtres');?></td>
						<td><input class="button" type="submit" name="delete" value=<?=__('Delete', 'courtres');?> /></td>
					</tr>
				<?php }?>
			</table>
		</form>

	<?php endif; ?>
</div>