<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://webmuehle.at
 * @since      1.0.3
 *
 * @package    Courtres
 * @subpackage Courtres/admin/partials
 */
?>

<?php
	if (!current_user_can('manage_options')) {
		wp_die();
	}
	if(isset($_REQUEST['export-expired']) && $_REQUEST['export-expired'] == 1) {
		$events = $this->get_expired('events');
		$this->export_csv( $this->prepare_to_csv($events) );
	}
	if(isset($_REQUEST['view-expired']) && $_REQUEST['view-expired'] == 1) {
		$events = $this->get_expired('events');
	}else{
		$days = $this->getWeekdays();

		$tab = (!empty($_GET['tab'])) ? esc_attr($_GET['tab']) : '0';
		$tab_where = " and weekly_repeat = 0 "; 
		if ($tab == '1') {
			$tab_where = " and weekly_repeat = 1 "; 
		}

		global $wpdb;
		$events = $wpdb->get_results("SELECT events.*, courts.name as courtname FROM {$this->getTable('events')} as events, 
			{$this->getTable('courts')} as courts
			WHERE courts.id=events.courtid {$tab_where} ORDER BY name");
	}

?>

<?php
include('courtres-notice-upgrade.php');
?>

<div class="wrap">
	<h1 class="wp-heading-inline"><?= __('Manage Events', 'courtres');?></h1>
	<a class="page-title-action" href="<?= admin_url("admin.php?page=courtres-event&tab=".$tab) ?>">
		<?php 
			if ($tab == '1') {
				?>
				<?= __('Create weekly event', 'courtres');?>
				<?php
			}else{
				?>
				<?= __('Create individual event', 'courtres');?>
				<?php 
			}
		?>
	</a>
	<div class="cr-head-right">
		<form method="post" action="<?php echo admin_url('admin-ajax.php'); ?>">
		   <?php wp_nonce_field('export_expired', 'export_expired_nonce'); ?>
			<input type="hidden" name="target" value="events" />
			<input type="hidden" name="action" value="download_csv" />
		   <?php submit_button(__("Export Expired", 'courtres')); ?>
		</form>
	</div>
	<div style="clear: both;"></div>
	<hr class="wp-header-end">

	<div class="cr-tabs-wrap">
		<div class="item1">
			<div class="cr-widget-right">
				<?php include 'courtres-widget-upgrade.php'; ?>
			</div>
		</div>
		<div  class="item2">
			<h2 class="nav-tab-wrapper wp-clearfix cr-nav-tab-wrapper">
				<a href="<?=admin_url("admin.php?page=courtres-events&tab=0");?>" class="nav-tab <?= $tab == '0' ? "nav-tab-active":"" ?>">
					<?=__('Individual events', 'courtres');?>
				</a>
				<a href="<?=admin_url("admin.php?page=courtres-events&tab=1");?>" class="nav-tab <?= $tab == '1' ? "nav-tab-active":"" ?>">
					<?=__('Weekly events', 'courtres');?>
				</a>
			</h2>

			<table class="wp-list-table widefat fixed striped posts">
				<thead>
					<tr>
						<th class="manage-column column-title column-primary"><?= __('Name', 'courtres');?></th>
						<th class="manage-column column-title column-primary"><?= __('Court', 'courtres');?></th>
						<?php 
							if ($tab == '1') {
								?>
								<th class="manage-column column-title column-primary">
									<?= __('Weekday', 'courtres');?>
								</th>
								<?php
							}else{
								?>
								<th class="manage-column column-title column-primary">
									<?= __('Date', 'courtres');?>
								</th>
								<?php 
							}
						?>
						<th class="manage-column column-title column-primary"><?= __('Period', 'courtres');?></th>
						<th class="manage-column column-title"><?= __('Action', 'courtres');?></th>
					</tr>
				</thead>
				<tbody>
					<?php foreach ($events as $item): ?>
						<?php 
							$period = $item->start . "-" . $item->end . "&nbsp;" . __('Hour', 'courtres');
							if( property_exists($item, "start_ts") && $item->start_ts ){
								$period = date_i18n("H:i", $item->start_ts);
							}
							if( property_exists($item, "end_ts") && $item->end_ts ){
								$period .= " - " . date_i18n("H:i", $item->end_ts);
							}
						?>
						<tr class="<?= (($item->weekly_repeat != 1) && $item->event_date < date("Y-m-d")) ? 'event-expired' : '' ?>">
							<td>
								<?= $item->name ?>
							</td>
							<td><?= $item->courtname ?></td>
							<?php 
								if ($tab == '1') {
									?>
									<td><?= $days[date('w', strtotime($item->event_date))] ?></td>
									<?php
								}else{
									?>
									<td><?= date_i18n(get_option('date_format'), strtotime($item->event_date)) ?></td>
									<?php 
								}
							?>
							<td>
								<?php echo $period; ?>
							</td>
							<td>
								<?php if($item->type != "challenge"): ?>
									<a class="page-action" href="<?= admin_url("admin.php?page=courtres-event&eventID={$item->id}&tab=$tab") ?>"><?= __('Edit', 'courtres');?></a>
								<?php endif; ?>
						</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
		</div>
	</div>
</div>
