<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://webmuehle.at
 * @since      1.0.3
 *
 * @package    Courtres
 * @subpackage Courtres/public/partials
 */
?>

<?php


	$atts = array_change_key_case((array)$atts, CASE_LOWER);
	if(!isset($atts['id'])) {echo(__("Court Reservation ID not set.",'courtres'));return;}
	$courtID = (int)$atts['id'];
	if($courtID==0) {echo(__("Court Reservation ID invalid.",'courtres'));return;}

	if (!$this->isCourtPremium($courtID)){
		echo(__("Free version allow one Court only.",'courtres'));
		return;
	}

	$court = $this->getCourtByID($courtID);
	if($court == null) {
		echo(__("Court not found.",'courtres'));
		return;
	}

	$mayEdit = current_user_can('place_reservation');
	$username = '';

	if (is_user_logged_in()) {
		$username = wp_get_current_user()->display_name;
	}
	
	$players = $this->getAvailablePlayers();

	$this->blocks = $this->getBlocksRepeatFutureByID($court->id);
	$this->reservations = $this->getCurrentReservationsByID($court->id, $court->days+1);
	$this->isReservatedPerPersonInFuture = $this->countUpcomingUserReservations( wp_get_current_user()->ID);
	$this->isSeveralReservePerson = $this->getOptionValue('several_reserve_person');

	$maxhours = $this->getMaxHours();
	$halfhour = $this->ishalfhour() ? '1' : '';
	$fromDay = isset($_SESSION['cr_from'])?intval($_SESSION['cr_from']):0; //$court->days;
	$tillDay =  $fromDay===0?$court->days:$fromDay+$court->days;
	$availableReservationTypes = $this->getAvailableReservationTypes();
	$maxPlayers = $this->getMaxPlayers();
	$dateformats = $this->getDateformats();
	$dateformat = $this->getDateFormat();
	$found_index = array_search("$dateformat", array_column($dateformats, 'format'));
	$isTeamMateMandatory = $this->isTeamMateMandatory();
	$dateFormatName = $dateformats[$found_index]["name"];
	$timeFormat = ($dateFormatName == "USA") ? "h:i a" : "H:i";
	$matchDurations = $this->getMatchDurations();
 
	
	$theTime = getCurrentDateTime();
	$nowTZ = new DateTime($theTime["datetime"]);
	$nowTZTS = $nowTZ->format('U');
	$nowUTC  = date_i18n('l', $nowTZTS);
?>



<!-- CR-DIALOG-RESERVE -->
<div id="cr-dialog-reserve-<?= $courtID ?>" class="cr-dialog-reserve" title="<?= $court->name ?> <?= __('Reservation', 'courtres');?>" style="display:none;">
	<form id="cr-form-reserve-<?= $courtID ?>" class="resform" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>" method="post" >
		<input type="hidden" name="action" value="add_reservation">
		<input type="hidden" name="courtid" value="<?= $court->id ?>" />
		<input type="hidden" name="maxhours" value="<?= $maxhours ?>" />
		<input type="hidden" name="halfhour" value="<?= $halfhour ?>" />
		<input type="hidden" name="date" />
		<input type="hidden" name="day" />
		<input type="hidden" name="hour" />
		<input type="hidden" name="minstart" />
		<!-- <input type="hidden" name="minend" /> -->
		<table class="table table-striped form-fields-table">
			<tr>
				<td><?= __('Date', 'courtres');?></td>
				<td>
					<div class="date"><span id="date">&ndash;</span></div>
					<!-- <span id="time">&ndash;</span> -->
				</td>
			</tr>
			<tr>
				<td><?= __('Player', 'courtres');?></td>
				<td>
					<?php if($mayEdit){ ?>
						<?= $username ?>
					<?php }else{ ?>
						<select name="playerid" id="playerid">
							<option value="0" selected>-</option>
							<?php for($day=0;$day<sizeof($players);$day++) { $player = $players[$day]; ?>
								<option value="<?= $player->user_login ?>"><?= $player->display_name ?></option>
							<?php } ?>
						</select>
						<div>
							<a class="login_button" id="cr-show-login"><?= __('Login', 'courtres');?></a>
						</div>
					<?php } ?>
				</td>
			</tr>
			<tr>
				<td><?= __('Type', 'courtres');?>*</td>
				<td>
					<select name="type" class="reservation-type-select" autocomplete="off" required>
						<option value=""><?= __("Select from list", 'courtres');?></option>
						<?php foreach ($availableReservationTypes as $type) :?>
							<option value="<?= __($type, 'courtres');?>" data-maxplayers="<?php echo $maxPlayers[$type]; ?>" data-duration="<?php echo $matchDurations[$type]; ?>"><?= __($type, 'courtres');?></option>
						<?php endforeach; ?>
					</select>
				</td>
			</tr>
		</table>
	</form>
	<div class="cr-preloader-overlay in-relative-block" id="plo-add-reserv"><div class="cr-preloader"></div></div>
</div>
<!-- 20.05.2019, astoian - colors -->
<?= $this->option_ui_tbl_brdr_clr() ?>
<?= $this->option_ui_tbl_bg_clr_1() ?>
<?= $this->option_ui_tbl_bg_clr_2() ?>
<?= $this->option_ui_tbl_bg_clr_3() ?>
<?= $this->option_ui_tbl_bg_clr_4() ?>
<?= $this->option_ui_link_clr() ?>
<?= $this->option_ui_button_clr() ?>
<?= $this->option_ui_table_cell_width() ?>
<?= $this->option_ui_table_cell_height() ?>
<?= $this->option_ui_table_cell_mouseover_background() ?>
<?= $this->option_ui_table_cell_mouseover_linktext() ?>

<!-- CR-TABLE -->
<div class="table-responsive container-reservations" id="cr-table-<?= $courtID ?>" data-hour-close="<?= $court->close ?>" data-navigator-step="<?= $court->days ?>">

	<?php if($mayEdit): ?>
		<?php echo $username; ?>&ensp;
		<a href="<?php echo wp_logout_url(add_query_arg($_GET)) ;?>" class="menu-link">Logout</a>
	<?php else: ?>
		<a href="<?php echo wp_login_url(add_query_arg($_GET)) ;?>" class="login-link menu-link">Login</a>
	<?php endif; ?>

	<?php if ($this->iscalenderviewnavigator()) { ?>
		<div class="navigator">
			<a class="button" id="cr-days-prev-<?= $courtID ?>" data-navigator="prev">
				<span>&lt;</span>
			</a>
			<a class="button" id="cr-days-today-<?= $courtID ?>" data-navigator="today">
				<span><?= __('Today', 'courtres'); ?></span>
			</a>
			<a class="button" id="cr-days-next-<?= $courtID ?>" data-navigator="next">
				<span>&gt;</span>
			</a>
			<div id="cr-today-my"><?= date_i18n('F', strtotime('+0 day', $nowTZTS)) . " " . date_i18n('Y', strtotime('+0 day', $nowTZTS)) ?></div>
		</div>
	<?php } ?>
	<table class="table reservations" id="cr-reservations-<?= $courtID ?>">
		<thead>
			<th><?= __('Time', 'courtres');?></th>
			<?php
				for($day=$fromDay; $day<$tillDay; $day++) {
					echo "<th>" . date_i18n('l', strtotime('+'.$day.' day', $nowTZTS)) . "<br/>" . date_i18n($dateformat, strtotime('+'.$day.' day', $nowTZTS)) . "</th>";
				}
			?>
		</thead>
		<tbody>
			<?php for($j=$court->open; $j<$court->close; $j++) { ?>
				<!-- hour row -->
				<tr>
					<?php
						// 2020-06-18 astoian: bug for ngix, time is not formated correcty for AM:FM
						//date_i18n( $timeFormat, strtotime( '2000-01-01 ' . $j . ':00' ) ); 
						$t0 = date($timeFormat, strtotime( $j . ':00') );
						if ($this->ishalfhour()) {
							$t1 = date( $timeFormat, strtotime( $j . ':00 + 30 min' ) );
						}else{
							$t1 = date( $timeFormat, strtotime( $j . ':00 + 1 hour') );
						}
						echo "<th>".($t0)." &ndash; ".($t1)."</th>";
					?>
					<?php
						for($day=$fromDay;$day<$tillDay;$day++) {
							echo $this->getTD( $court, $day, $j, 0, 30, date_i18n("Y-m-d", strtotime('+'.$day.' day', $nowTZTS)) );
						}
					?>
				</tr>
				<!-- half hour row -->
				<?php if ($this->ishalfhour()) { ?>
					<tr>
						<?php
							$t0 = date( $timeFormat, strtotime( $j . ':00 + 30 min' ) );
							$t1 = date( $timeFormat, strtotime( $j . ':00 + 1 hour' ) );
							$fromto = "<th>".($t0)." &ndash; ".($t1)."</th>";
							echo $fromto;
						?>
						<?php
							for($day=$fromDay;$day<$tillDay;$day++) {
								echo $this->getTD( $court, $day, $j, 30, 0, date_i18n("Y-m-d", strtotime('+'.$day.' day', $nowTZTS)) );
							}
						?>
					</tr>
				<?php } ?>
			<?php } ?>
		</tbody>
	</table>
</div>

<!-- CR-DIALOG-LOGIN -->
<?php if ( !is_user_logged_in() ) { ?>
	<div id="cr-dialog-login-<?= $courtID ?>" title="<?= __('Login', 'courtres'); ?>" style="display:none">
		<div id="login-error" style="display:none">
			<strong><?= __('ERROR', 'courtres'); ?></strong>: <span id="login-error-text"></span>
			<!-- <a class="lost" href="<?php echo wp_lostpassword_url(); ?>"><?= __('Forgot password?', 'courtres'); ?></a> -->
		</div>
		<form id="cr-form-login-<?= $courtID ?>" class="cr-login-form" method="post" action="<?php echo esc_url( admin_url( 'admin-ajax.php') ); ?>"> 
			<input type="hidden" name="action" value="ajax_login">
			<table class="table table-striped">
					<tr>
						<td>
							<label><?= __('Login', 'courtres');?></label>
							<input id="username" type="text" name="username">
						</td>
					</tr>
					<tr>
						<td>
							<label><?= __('Password', 'courtres');?></label>
							<input id="password" type="password" name="password">
							<a class="lost" href="<?php echo wp_lostpassword_url(); ?>"><?= __('Forgot password?', 'courtres'); ?></a>
						</td>
					</tr>
				</table>
			<?php wp_nonce_field( 'ajax-login-nonce', 'security' ); ?>
		</form>
	</div>
<?php } ?>